<?php
/**
 * XEvent functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package XEvent
 */

if ( ! function_exists( 'xevent_setup' ) ) :


function xevent_setup() {

	// Load the TGM init if it exists
    if ( file_exists( get_template_directory() . '/inc/init/tgm/tgm-init.php' ) ) {
        require_once get_template_directory() . '/inc/init/tgm/tgm-init.php';
    }

	if ( class_exists('ReduxFrameworkPlugin') ) {
		//THEME OPTIONS
		require get_template_directory() . '/inc/init/admin-init.php';	
	}

	
	
	global $xevent_var;
	global $xevent_font_icons; 

	$xevent_var = get_option('xevent_var');

	// theme version.
	if ( ! defined( 'THEME_VERSION' ) ) {
	    define( 'THEME_VERSION', '1.0.0' );
	}

	// WELCOME SCREEN
	if ( file_exists( get_template_directory() . '/inc/welcome/welcome-init.php' ) ) {
	    require_once( get_template_directory() . '/inc/welcome/welcome-init.php' );
	}

	if ( file_exists( get_template_directory() . '/inc/welcome/welcome-logic.php' ) ) {
	    require_once( get_template_directory() . '/inc/welcome/welcome-logic.php' );
	}

	
	//NAVIGATION
	require_once get_template_directory() . '/inc/wp_bootstrap_navwalker.php';

	
	//REDUX DEMO MODE DISABLE
	function xevent_removeDemoModeLink() { // Be sure to rename this function to something more unique
		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
		}
		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_action('Redux_Admin_Notices', array( ReduxFrameworkPlugin::get_instance(), 'Redux_Admin_Notices' ) );    
		}
	}
	add_action('init', 'xevent_removeDemoModeLink');


	//WOOCOMMERCE SUPPORT
	add_theme_support( 'woocommerce' );

	//EVENTBRITE SUPPORT
	add_theme_support( 'eventbrite' );

	//TEXTDOMAIN
	load_theme_textdomain( 'xevent', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	add_image_size( 'xevent-speaker-thumb-circle', 100, 100, true );
	add_image_size('xevent-speaker-mini-thumb', 50, 50, true );
	add_image_size('xevent-recent-posts-widget', 60,60, true);

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'xevent' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );
	

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
}
endif;
add_action( 'after_setup_theme', 'xevent_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function xevent_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'xevent_content_width', 640 );
}
add_action( 'after_setup_theme', 'xevent_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function xevent_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'xevent' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'xevent' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Shop Sidebar', 'xevent' ),
		'id'            => 'shop',
		'description'   => esc_html__( 'Add widgets here.', 'xevent' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	// First footer widget area, located in the footer. Empty by default.
    register_sidebar( array(
        'name' => __( 'Footer Widget Area 1', 'xevent' ),
        'id' => 'first-footer-widget-area',
        'description' => __( 'The first footer widget area', 'xevent' ),
        'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5 class="widget-title uppercase">',
        'after_title' => '</h5>',
    ) );
 
    // Second Footer Widget Area, located in the footer. Empty by default.
    register_sidebar( array(
        'name' => __( 'Footer Widget Area 2', 'xevent' ),
        'id' => 'second-footer-widget-area',
        'description' => __( 'The second footer widget area', 'xevent' ),
        'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5 class="widget-title uppercase">',
        'after_title' => '</h5>',
    ) );
 
    // Third Footer Widget Area, located in the footer. Empty by default.
    register_sidebar( array(
        'name' => __( 'Footer Widget Area 3', 'xevent' ),
        'id' => 'third-footer-widget-area',
        'description' => __( 'The third footer widget area', 'xevent' ),
        'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5 class="widget-title uppercase">',
        'after_title' => '</h5>',
    ) );

    // Fourth Footer Widget Area, located in the footer. Empty by default.
    register_sidebar( array(
        'name' => __( 'Footer Widget Area 4', 'xevent' ),
        'id' => 'fourth-footer-widget-area',
        'description' => __( 'The third footer widget area', 'xevent' ),
        'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5 class="widget-title uppercase">',
        'after_title' => '</h5>',
    ) );
}
add_action( 'widgets_init', 'xevent_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function xevent_scripts() {

	wp_enqueue_script("bootstrap-min", get_template_directory_uri()."/js/bootstrap.min.js",array('jquery'),false,true);
	wp_enqueue_script("rainbow", get_template_directory_uri()."/js/rainbow.min.js",array('jquery'),false,true);
	wp_enqueue_script("mousewheel", get_template_directory_uri()."/js/jquery.mousewheel.min.js",array(),false,true);
	wp_enqueue_script("mCustomScrollbar", get_template_directory_uri()."/js/jquery.mCustomScrollbar.min.js",array(),false,true);
	wp_enqueue_script("timecircles", get_template_directory_uri()."/js/timecircles.js",array(),false,true);
	wp_enqueue_script("retina", get_template_directory_uri()."/js/retina.min.js",array(),false,true);
	wp_enqueue_script("owl-carousel", get_template_directory_uri()."/js/owl.carousel.min.js",array(),false,true);
	wp_enqueue_script("waypoints", get_template_directory_uri()."/js/jquery.waypoints.min.js",array(),false,true);
	wp_enqueue_script("counterup", get_template_directory_uri()."/js/jquery.counterup.min.js",array(),false,true);
	wp_enqueue_script("magnific-popup", get_template_directory_uri()."/js/jquery.magnific-popup.min.js",array(),false,true);
	wp_enqueue_script("imagesloaded", get_template_directory_uri()."/js/imagesloaded.pkgd.min.js",array(),false,true);
	wp_enqueue_script("masonry", get_template_directory_uri()."/js/masonry.pkgd.min.js",array(),false,true);
	wp_enqueue_script("masonry-ordered", get_template_directory_uri()."/js/masonry.ordered.js",array(),false,true);
	wp_enqueue_script("modernizr", get_template_directory_uri()."/js/modernizr.js",array(),false,true);

	if ( is_rtl() ) {
	  wp_dequeue_script('owl-carousel');
	  wp_enqueue_script("owl-carousel-rtl", get_template_directory_uri()."/js/owl.carousel-rtl.js",array(),false,true);
	}

	wp_enqueue_script("xevent-scripts", get_template_directory_uri()."/js/scripts.js",array(),false,true);

	if ( is_rtl() ) {
	  wp_dequeue_script('xevent-scripts');
	  wp_enqueue_script("xevent-scripts-rtl", get_template_directory_uri()."/js/scripts-rtl.js",array(),false,true);
	}

	/* styles */
	wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.min.css');
	wp_enqueue_style( 'pe-7-icon', get_template_directory_uri().'/css/pe-icon-7-stroke.css');
	wp_enqueue_style( 'linearicons', get_template_directory_uri().'/css/linear-icons.css');
	wp_enqueue_style( 'davicons', get_template_directory_uri().'/css/davicons.css');
	wp_enqueue_style( 'helper', get_template_directory_uri().'/css/helper.css');
	/* wp_enqueue_style( 'fontawesome', get_template_directory_uri().'/css/font-awesome.min.css'); */
	wp_enqueue_style( 'timecircles', get_template_directory_uri().'/css/timecircles.css');
	wp_enqueue_style( 'magnific-popup', get_template_directory_uri().'/css/magnific-popup.css');
	wp_enqueue_style( 'mCustomScrollbar', get_template_directory_uri().'/css/jquery.mCustomScrollbar.min.css');
	wp_enqueue_style( 'owl-carousel', get_template_directory_uri().'/css/owl.carousel.css');
	wp_style_add_data( 'owl-carousel', 'rtl', 'replace' );
	wp_enqueue_style( 'owl-theme', get_template_directory_uri().'/css/owl.theme.css');
	wp_enqueue_style( 'animate', get_template_directory_uri().'/css/animate.css');
	wp_enqueue_style( 'fonts', get_template_directory_uri().'/css/fonts.css');
	wp_enqueue_style( 'woo', get_template_directory_uri().'/css/woocommerce.css');
	wp_style_add_data( 'woo', 'rtl', 'replace' );
	wp_enqueue_style( 'xevent-style', get_stylesheet_uri() );
	wp_style_add_data( 'xevent-style', 'rtl', 'replace' );


	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	if (is_plugin_active( 'themecube-core/themecube-core.php' )) {
		wp_enqueue_style( 'dynamic-css', get_template_directory_uri().'/style.php');

    };

	

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	
}
add_action( 'wp_enqueue_scripts', 'xevent_scripts' );



//CUSTOM CSS
if (!function_exists('xevent_custom_css')) {
	function xevent_custom_css(){
		$xevent_var = get_option('xevent_var');

		if (!empty($xevent_var['css_editor'])){
			echo '<style type="text/css"> '.$xevent_var['css_editor'].'</style>';}
		}
}


add_action('wp_enqueue_style','xevent_custom_css');

//CUSTOM JS
if (!function_exists('xevent_custom_js')) {
	function xevent_custom_js(){
		$xevent_var = get_option('xevent_var');

		if (!empty($xevent_var['js_editor'])){
			echo '<script> '.$xevent_var['js_editor'].'</script>';
		}

	}
}

add_action('wp_enqueue_script','xevent_custom_js');


/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';


function xevent_do_shortcode($content) {
    global $shortcode_tags;
    if (empty($shortcode_tags) || !is_array($shortcode_tags))
        return $content;
    $pattern = get_shortcode_regex();
    return preg_replace_callback( "/$pattern/s", 'do_shortcode_tag', $content );
}

/* Visual Composer */
if(function_exists('vc_add_param')){
 
  vc_add_param('vc_row',array(
        "type" => "dropdown",
        "heading" => esc_html__('Fullwidth', 'xevent'),
        "param_name" => "fullwidth",
        "value" => array(   
                esc_html__('No', 'xevent') => 'no',  
                esc_html__('Yes', 'xevent') => 'yes',                                                                                
                ),
        "description" => esc_html__("Select Fullwidth or not", 'xevent'), 
        'weight' => 1,     
      ) 
    );
	
	vc_add_param('vc_row_inner',array(
        "type" => "dropdown",
        "heading" => esc_html__('Fullwidth', 'xevent'),
        "param_name" => "fullwidth",
        "value" => array(   
                esc_html__('No', 'xevent') => 'no',  
                esc_html__('Yes', 'xevent') => 'yes',                                                                                
                ),
        "description" => esc_html__("Select Fullwidth or not", 'xevent'),
        'weight' => 1,     
      ) 
    );
	

} 

if (!function_exists('xevent_connect_speaker_program')) {

	function xevent_connect_speaker_program() {
	    p2p_register_connection_type( array(
	        'name' => 'speaker_program',
	        'from' => 'speaker',
	        'to' => 'schedule'
	    ) );
	}

	add_action( 'p2p_init', 'xevent_connect_speaker_program' );

}

if (!function_exists('xevent_connect_speaker_wshop')) {

	function xevent_connect_speaker_wshop() {
	    p2p_register_connection_type( array(
	        'name' => 'speaker_wshop',
	        'from' => 'speaker',
	        'to' => 'workshop'
	    ) );
	}

	add_action( 'p2p_init', 'xevent_connect_speaker_wshop' );

}
//Excerpt More
function xevent_excerpt_more( $more ) {
    return '';
}
add_filter( 'excerpt_more', 'xevent_excerpt_more' );



//Backend CSS
if ( !function_exists( 'xevent_backend_css' ) ) {
	
	function xevent_backend_css() {	                           		
		wp_enqueue_style( 'pe-7-icon', get_template_directory_uri().'/css/pe-icon-7-stroke.css', false, '', 'all');
		wp_enqueue_style( 'linearicons', get_template_directory_uri().'/css/linear-icons.css');
		wp_enqueue_style( 'davicons', get_template_directory_uri().'/css/davicons.css');
		wp_enqueue_style( 'admin-css', get_template_directory_uri().'/css/admin.css', false, '', 'all' );
		wp_style_add_data( 'admin-css', 'rtl', 'replace' );
		wp_enqueue_style( 'fonts', get_template_directory_uri().'/css/fonts.css');
		wp_enqueue_script("cmb2-conditionals", get_template_directory_uri()."/js/cmb2-conditionals.js",array('jquery'),false,true);

        }
		        
	// Pe Icon fonts for backend
    add_action( 'admin_enqueue_scripts', 'xevent_backend_css' );                   
}

/* Read More */
if ( !function_exists( 'xevent_modify_read_more_link' ) ) {
    function xevent_modify_read_more_link() {

        global $xevent_var;
        $read_more_text = isset( $xevent_var['blog-continue-reading'] ) ? sanitize_text_field( $xevent_var['blog-continue-reading'] ) : esc_html__( 'Read more', 'xevent' );
        return '<a class="read-more-button common-button common-button-dark button-sm" href="' . get_permalink() . '">' . $read_more_text . '</a>';
    }
    add_filter( 'the_content_more_link', 'xevent_modify_read_more_link' );
  }
  
/*  */
if ( !function_exists( 'xevent_get_the_excerpt_max_charlength' ) ) {
    function xevent_get_the_excerpt_max_charlength( $charlength ) {
    	$excerpt = get_the_excerpt();
        
    	$charlength++;
    
    	if ( mb_strlen( $excerpt ) > $charlength ) {
    		$subex = mb_substr( $excerpt, 0, $charlength - 5 );
    		$exwords = explode( ' ', $subex );
    		$excut = - ( mb_strlen( $exwords[ count( $exwords ) - 1 ] ) );
    		if ( $excut < 0 ) {
    			$subex = mb_substr( $subex, 0, $excut );
    		} 
    		$subex .= '...';
            $excerpt = $subex;
    	} 
        
        return $excerpt;
    }   
}



//WOOCOMMERCE

// Change number or products per row to 3
add_filter('loop_shop_columns', 'xevent_loop_columns');
if (!function_exists('xevent_loop_columns')) {
	function xevent_loop_columns() {
		return 3; // 3 products per row
	}
}

add_filter( 'loop_shop_per_page', create_function( '$cols', 'return 9;' ), 20 );


//Reposition WooCommerce breadcrumb 
function xevent_woo_remove_breadcrumb(){
remove_action( 
    'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20);
}
add_action(
    'woocommerce_before_main_content', 'xevent_woo_remove_breadcrumb'
);

function xevent_woo_custom_breadcrumb(){
    woocommerce_breadcrumb();
}

add_action( 'woo_custom_breadcrumb', 'xevent_woo_custom_breadcrumb' );



//XEvent Demo Import
if ( !function_exists( 'xevent_demo_import' ) ) {
	function xevent_demo_import( $demo_active_import , $demo_directory_path ) {

		reset( $demo_active_import );
		$current_key = key( $demo_active_import );

		//Rev Slider

		if ( class_exists( 'RevSlider' ) ) {

			$wbc_sliders_array = array(
				'main' => 'fulscreen-image.zip', 'video-bg.zip', //Set slider zip name
				'startup' =>'video-bg.zip',
				'summit' =>'summit-hero.zip',
			);

			if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && array_key_exists( $demo_active_import[$current_key]['directory'], $wbc_sliders_array ) ) {
				$wbc_slider_import = $wbc_sliders_array[$demo_active_import[$current_key]['directory']];

				if ( file_exists( $demo_directory_path.$wbc_slider_import ) ) {
					$slider = new RevSlider();
					$slider->importSliderFromPost( true, true, $demo_directory_path.$wbc_slider_import );
				}
			}
		}

		//Set Menus

		$wbc_menu_array = array( 'main', 'startup', 'summit' );

		if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && in_array( $demo_active_import[$current_key]['directory'], $wbc_menu_array ) ) {
			$primary = get_term_by( 'name', 'primary', 'nav_menu' );
			

				set_theme_mod( 'nav_menu_locations', array(
						'primary' => $primary->term_id,
					)
				);

		}

		//Set Homepage

		$wbc_home_pages = array(
			'main' => 'Homepage',
			'startup' => 'Homepage',
			'summit' => 'Homepage',
			
		);

		if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && array_key_exists( $demo_active_import[$current_key]['directory'], $wbc_home_pages ) ) {
			$page = get_page_by_title( $wbc_home_pages[$demo_active_import[$current_key]['directory']] );
			if ( isset( $page->ID ) ) {
				update_option( 'page_on_front', $page->ID );
				update_option( 'show_on_front', 'page' );
			}
		}


	}


	// Uncomment the below
	 add_action( 'wbc_importer_after_content_import', 'xevent_demo_import', 10, 2 );
}



 function xevent_shortcode_empty_paragraph_fix( $content ) {

    $array = array (
        '<p>[' => '[',
        ']</p>' => ']',
        ']<br />' => ']'
    );

    $content = strtr( $content, $array );

    return $content;
}

add_filter( 'the_content', 'xevent_shortcode_empty_paragraph_fix' );



function xevent_comment($comment, $args, $depth) {



    if ( 'div' === $args['style'] ) {
    	
        $tag       = 'div';
        $add_below = 'all';
    } else {
        $tag       = 'li';
        $add_below = 'div-comment';
    }

    ?> 

    <<?php echo esc_html($tag) ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
        <div id="div-comment-<?php comment_ID() ?>" class="comment-body">
    <?php endif; ?>
    <div class="comment-author vcard">
        <?php if ( $args['avatar_size'] != 0 ) echo get_avatar( $comment, $args['avatar_size'] ); ?>
        <?php printf( ( '<p class="cmntr">%s</p>' ), get_comment_author_link() ); ?>
    </div>

    <div class="comment-content">
    <?php if ( $comment->comment_approved == '0' ) : ?>
         <em class="comment-awaiting-moderation"><?php __( 'Your comment is awaiting moderation.', 'xevent' ); ?></em>
          <br />
    <?php endif; ?>

    <div class="comment-meta commentmetadata"><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>">
        <?php
        printf( '%1$s', get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Edit)', 'xevent' ), '  ', '' );
        ?>
    </div>

    <?php comment_text(); ?>

    <div class="reply">
        <?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
    </div>
	</div>
    <?php if ( 'div' != $args['style'] ) : ?>
    </div>
    <?php endif; ?>
    <?php
}

// YOAST SEO
add_action('template_redirect','remove_wpseo');

function remove_wpseo(){
 
    if (! is_front_page() ) {
        global $wpseo_front;
            if(defined($wpseo_front)){
                remove_action('wp_head',array($wpseo_front,'head'),1);
            }
            else {
              $wp_thing = WPSEO_Frontend::get_instance();
              remove_action('wp_head',array($wp_thing,'head'),1);
            }
    } 
}

